@@ -565,7 +565,7 @@ pipeline_error_cb (GstBus * bus, GstMessage * msg, GSRWindow * window)
 	set_action_sensitive (window, "Stop", FALSE);
 	set_action_sensitive (window, "Play", TRUE);
 	set_action_sensitive (window, "Record", TRUE);
-	set_action_sensitive (window, "FileSave", FALSE);
+	set_action_sensitive (window, "FileSave", TRUE);
 	set_action_sensitive (window, "FileSaveAs", TRUE);
 	gtk_widget_set_sensitive (window->priv->scale, TRUE);
 
@@ -662,11 +662,12 @@ do_save_file (GSRWindow *window,
 
         profile = gm_audio_profile_choose_get_active (priv->profile);
 
-	if (g_str_has_suffix (_name, gm_audio_profile_get_extension (profile)))
+	if (window->priv->extension == NULL ||
+	    g_str_has_suffix (_name, window->priv->extension))
 		name = g_strdup (_name);
 	else
 		name = g_strdup_printf ("%s.%s", _name,
-			       gm_audio_profile_get_extension (profile));
+				window->priv->extension);
 	if (g_file_test (name, G_FILE_TEST_EXISTS)) {
 		if (!replace_existing_file (GTK_WINDOW (window), name))
 			return;
@@ -746,10 +747,11 @@ file_save_as_cb (GtkAction *action,
 
 		filename = g_strndup (basename,length);
 		profile = gm_audio_profile_choose_get_active (window->priv->profile);
-		g_free (window->priv->extension);
-
-		window->priv->extension = g_strdup (gm_audio_profile_get_extension (profile));
-		filename_ext = g_strdup_printf ("%s.%s", filename , window->priv->extension);
+		if (window->priv->extension)
+			filename_ext = g_strdup_printf ("%s.%s", filename,
+						window->priv->extension);
+		else
+			filename_ext = g_strdup (filename);
 		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (file_chooser),
 						   filename_ext);
 		g_free (filename);
@@ -776,8 +778,6 @@ file_save_as_cb (GtkAction *action,
 	}
 
 	gtk_widget_destroy (file_chooser);
-
-	window->priv->quit_after_save = FALSE;
 }
 
 
@@ -785,13 +785,7 @@ static void
 file_save_cb (GtkAction *action,
 	      GSRWindow *window)
 {
-	if (window->priv->filename == NULL ||
-	    /* Translator comment: Untitled here implies a track without a
-	     * name. See also the translation in gnome-recorder.c:94. Those
-	     * two strings should match! If the track is unnamed, we will
-	     * open the save-as dialog here, else we´ll use the given file
-	     * to save to. */
-	    g_strrstr (window->priv->filename, _("Untitled")) == 0) {
+	if (window->priv->dirty) {
 		file_save_as_cb (NULL, window);
 	} else {
 		do_save_file (window, window->priv->filename);
@@ -1482,7 +1476,7 @@ play_state_changed_cb (GstBus * bus, GstMessage * msg, GSRWindow * window)
 		set_action_sensitive (window, "Stop", FALSE);
 		set_action_sensitive (window, "Play", TRUE);
 		set_action_sensitive (window, "Record", TRUE);
-		set_action_sensitive (window, "FileSave", window->priv->dirty ? TRUE : FALSE);
+		set_action_sensitive (window, "FileSave", TRUE);
 		set_action_sensitive (window, "FileSaveAs", TRUE);
 
 		gtk_statusbar_pop (GTK_STATUSBAR (window->priv->statusbar),
@@ -1702,6 +1696,7 @@ static void
 record_state_changed_cb (GstBus *bus, GstMessage *msg, GSRWindow *window)
 {
 	GstState  new_state;
+	GMAudioProfile *profile;
 
 	gst_message_parse_state_changed (msg, NULL, &new_state, NULL);
 
@@ -1718,6 +1713,9 @@ record_state_changed_cb (GstBus *bus, GstMessage *msg, GSRWindow *window)
 	switch (new_state) {
 	case GST_STATE_PLAYING:
 		window->priv->record_id = g_idle_add (record_start, window);
+		g_free (window->priv->extension);
+		profile = gm_audio_profile_choose_get_active (window->priv->profile);
+		window->priv->extension = g_strdup (gm_audio_profile_get_extension (profile));
 		gtk_widget_set_sensitive (window->priv->profile, FALSE);
 		gtk_widget_set_sensitive (window->priv->input, FALSE);
 		break;
@@ -1731,7 +1729,7 @@ record_state_changed_cb (GstBus *bus, GstMessage *msg, GSRWindow *window)
 		set_action_sensitive (window, "Stop", FALSE);
 		set_action_sensitive (window, "Play", TRUE);
 		set_action_sensitive (window, "Record", TRUE);
-		set_action_sensitive (window, "FileSave", window->priv->dirty ? TRUE : FALSE);
+		set_action_sensitive (window, "FileSave", TRUE);
 		set_action_sensitive (window, "FileSaveAs", TRUE);
 		gtk_widget_set_sensitive (window->priv->scale, FALSE);
 
@@ -2153,6 +2151,7 @@ gsr_window_init (GSRWindow *window)
 	gtk_widget_show (menubar);
 
 	toolbar = gtk_ui_manager_get_widget (priv->ui_manager, "/ToolBar");
+	gtk_toolbar_set_show_arrow (GTK_TOOLBAR (toolbar), FALSE);
 	gtk_box_pack_start (GTK_BOX (main_vbox), toolbar, FALSE, FALSE, 0);
 	gtk_widget_show (toolbar);
 
@@ -2316,6 +2315,7 @@ gsr_window_set_property (GObject      *object,
 	GSRWindowPrivate *priv;
 	struct stat buf;
 	char *title, *short_name;
+	const char *ext;
 
 	window = GSR_WINDOW (object);
 	priv = window->priv;
@@ -2342,6 +2342,12 @@ gsr_window_set_property (GObject      *object,
 			window->priv->has_file = FALSE;
 		}
 
+		g_free (window->priv->extension);
+		if ((ext = strrchr (short_name, '.')) && ext[1] != '\0')
+			window->priv->extension = g_strdup (&ext[1]);
+		else
+			window->priv->extension = NULL;
+
 		if (priv->name_label != NULL) {
 			gtk_label_set (GTK_LABEL (priv->name_label), short_name);
 		}
@@ -2358,7 +2364,7 @@ gsr_window_set_property (GObject      *object,
 		set_action_sensitive (window, "Play", window->priv->has_file ? TRUE : FALSE);
 		set_action_sensitive (window, "Stop", FALSE);
 		set_action_sensitive (window, "Record", TRUE);
-		/* set_action_sensitive (window, "FileSave", FALSE); */
+		set_action_sensitive (window, "FileSave", window->priv->has_file ? TRUE : FALSE);
 		set_action_sensitive (window, "FileSaveAs", window->priv->has_file ? TRUE : FALSE);
 		break;
 	default:
