@@ -125,19 +125,20 @@ static gboolean
 cb_check (gpointer data)
 {
   GnomeVolumeControlTrack *trkw = data;
+  gboolean mute, record;
+  gboolean vol_is_zero = FALSE, slider_is_zero = FALSE;
 
   /* trigger an update of the mixer state */
-  if (! GST_IS_MIXER_OPTIONS (trkw->track)) {
-    gint *dummy = g_new (gint, 1);
+  if (!GST_IS_MIXER_OPTIONS (trkw->track)) {
+    gint *dummy = g_new (gint, GST_MIXER_TRACK (trkw->track)->num_channels);
     gst_mixer_get_volume (trkw->mixer, GST_MIXER_TRACK (trkw->track), dummy);
     g_free (dummy);
   }
   
-  gboolean mute = GST_MIXER_TRACK_HAS_FLAG (trkw->track,
-				GST_MIXER_TRACK_MUTE) ? TRUE : FALSE,
-           record = GST_MIXER_TRACK_HAS_FLAG (trkw->track,
+  mute = GST_MIXER_TRACK_HAS_FLAG (trkw->track,
+				GST_MIXER_TRACK_MUTE) ? TRUE : FALSE;
+  record = GST_MIXER_TRACK_HAS_FLAG (trkw->track,
 				GST_MIXER_TRACK_RECORD) ? TRUE : FALSE;
-  gboolean vol_is_zero = FALSE, slider_is_zero = FALSE;
 
   if (trkw->sliderbox) {
     gnome_volume_control_volume_ask (
